@@ -107,7 +107,6 @@ class App extends React.Component {
             );
             console.log("finsh global.qtObjects = channel.objects...");
             global.qtObjects.manual.finishChannel();
-            global.qtObjects.manual.renderFinish();
         });
 
     }
@@ -403,11 +402,33 @@ class App extends React.Component {
                         let d = document.createElement('div');
                         d.innerHTML = html;
                         let dlist = d.querySelectorAll(`[text="${title}"]`);
-                        let hashID = 'h0';
-                        for (let i = 0; i < dlist.length; i++) {                           
-                                hashID = dlist[i].id;                          
+                        if(dlist.length == 0)
+                        {
+                            var translatePromise = new Promise(function(resolve, reject) {
+                                global.qtObjects.manual.translateTitle(title, function(titleTr) {
+                                    title = titleTr;
+                                    resolve()
+                                })
+                            });
+
+                            translatePromise.then(() => {
+                                dlist = d.querySelectorAll(`[text="${title}"]`);
+                                let hashID = 'h0';
+                                for (let i = 0; i < dlist.length; i++) {                           
+                                        hashID = dlist[i].id;                          
+                                }
+                                global.open(file, hashID);
+                            });
                         }
-                        global.open(file, hashID);
+                        else
+                        { 
+                            let hashID = 'h0';
+                            for (let i = 0; i < dlist.length; i++) {                           
+                                    hashID = dlist[i].id;                          
+                            }
+                            global.open(file, hashID);}
+                        
+                       
                     })
                 });
             } else {
@@ -483,6 +504,8 @@ class App extends React.Component {
                 document.documentElement.style.setProperty(`--nav-background-color`, '#282828');
                 document.documentElement.style.setProperty(`--nav-h2-word-color`, '#C0C6D4');
                 document.documentElement.style.setProperty(`--nav-h3-word-color`, '#C0C0C0');
+                document.documentElement.style.setProperty('--nav-hove-word-color', '#C0C6D4');
+                document.documentElement.style.setProperty('--nav-hove-border-color', 'rgba(0, 0, 0, 0.3)');
                 //document.documentElement.style.setProperty(`--nav-hash-word-color`, '#0059D2');     //btnlist 改这行
                 document.documentElement.style.setProperty(`--article-read-word-color`, '#C0C6D4');
                 document.documentElement.style.setProperty(`--article-read-h2-word-color`, '#0082FA');
@@ -498,9 +521,9 @@ class App extends React.Component {
                 document.documentElement.style.setProperty(`--search-items-word-color`, '#6D7C88');
                 document.documentElement.style.setProperty(`--search-items-resultnum-word-color`, '#6D7C88');
                 document.documentElement.style.setProperty(`--search-item-background-color`, 'rgba(255,255,255,0.05)');
-                document.documentElement.style.setProperty(`--scrollbar-div-background-color`, '#444444');
-                document.documentElement.style.setProperty(`--scrollbar-div-hover-background-color`, '#3D3D3D');
-                document.documentElement.style.setProperty(`--scrollbar-div-select-background-color`, '#303B69');
+                document.documentElement.style.setProperty(`--scrollbar-div-background-color`, 'rgba(255,255,255,0.2)');
+                document.documentElement.style.setProperty(`--scrollbar-div-hover-background-color`, 'rgba(255,255,255,0.25)');
+                document.documentElement.style.setProperty(`--scrollbar-div-select-background-color`, 'rgba(255,255,255,0.3)');
                 document.documentElement.style.setProperty(`--index-h2-color`, 'rgba(255,255,255,0.05)');
                 document.documentElement.style.setProperty(`--search-button-background-color-start`, '#484848');
                 document.documentElement.style.setProperty(`--search-button-background-color-end`, '#414141');
@@ -520,6 +543,8 @@ class App extends React.Component {
                 document.documentElement.style.setProperty(`--nav-background-color`, '#FFFFFF');
                 document.documentElement.style.setProperty(`--nav-h2-word-color`, '#001A2E');
                 document.documentElement.style.setProperty(`--nav-h3-word-color`, '#001A2E');
+                document.documentElement.style.setProperty('--nav-hove-word-color', '#000000');
+                document.documentElement.style.setProperty('--nav-hove-border-color', 'rgba(0, 0, 0, 0.05)'); 
                 // document.documentElement.style.setProperty(`--nav-hash-word-color`, '#ca0c16');   //btn list 改这一行
                 document.documentElement.style.setProperty(`--article-read-word-color`, '#000000');
                 document.documentElement.style.setProperty(`--article-read-h2-word-color`, '#2CA7F8');
@@ -535,9 +560,9 @@ class App extends React.Component {
                 document.documentElement.style.setProperty(`--search-items-word-color`, '#000000');
                 document.documentElement.style.setProperty(`--search-items-resultnum-word-color`, '#8AA1B4');
                 document.documentElement.style.setProperty(`--search-item-background-color`, 'rgba(255,255,255,1)');
-                document.documentElement.style.setProperty(`--scrollbar-div-background-color`, 'rgba(83,96,118,0.4)');
-                document.documentElement.style.setProperty(`--scrollbar-div-hover-background-color`, 'rgba(83,96,118,0.5)');
-                document.documentElement.style.setProperty(`--scrollbar-div-select-background-color`, 'rgba(83,96,118,0.6)');
+                document.documentElement.style.setProperty(`--scrollbar-div-background-color`, 'rgba(0,0,0,0.3)');
+                document.documentElement.style.setProperty(`--scrollbar-div-hover-background-color`, 'rgba(0,0,0,0.5)');
+                document.documentElement.style.setProperty(`--scrollbar-div-select-background-color`, 'rgba(0,0,0,0.4)');
                 document.documentElement.style.setProperty(`--index-h2-color`, 'rgba(0, 0, 0, 0.1)');
                 document.documentElement.style.setProperty(`--search-button-background-color-start`, '#E6E6E6');
                 document.documentElement.style.setProperty(`--search-button-background-color-end`, '#E3E3E3');
