@@ -20,14 +20,14 @@
 #define UT_ARGUMENT_PARSER_TEST_H
 
 #include "gtest/gtest.h"
-#include <QTest>
 
-namespace dman {
+#include <QTest>
+#include <QObject>
 
 class ut_argument_parser_test : public testing::Test
 {
 public:
     ut_argument_parser_test();
 };
-} // namespace dman
+
 #endif // UT_ARGUMENT_PARSER_TEST_H
