@@ -19,8 +19,11 @@
 #define UT_HELPERMANAGER_H
 
 #include "gtest/gtest.h"
+
 #include <QObject>
 #include <QTest>
+#include <QWebEngineView>
+#include <QStandardPaths>
 
 class helperManager;
 
@@ -33,6 +36,11 @@ public:
     virtual void SetUp() override;
     virtual void TearDown() override;
     helperManager *m_hm = nullptr;
+    QWebEnginePage* stub_page();
+    void stub_setWeb(QWebChannel * webchannel);
+    QString stub_writableLocation(QStandardPaths::StandardLocation type);
+
+    QWebChannel * webchannel = nullptr;
 
 };
 
