@@ -22,12 +22,10 @@
 #include "gtest/gtest.h"
 #include <QTest>
 
-namespace dman {
-
 class ut_window_manager_test : public ::testing::Test
 {
 public:
     ut_window_manager_test();
 };
-} // namespace dman
+
 #endif // UT_WINDOW_MANAGER_TEST_H
