@@ -4,12 +4,11 @@
 #include "gtest/gtest.h"
 #include <QTest>
 
-namespace dman {
 
 class ut_theme_proxy_test : public testing::Test
 {
 public:
     ut_theme_proxy_test();
 };
-}
+
 #endif // UT_THEME_PROXY_TEST_H
