@@ -21,13 +21,11 @@
 #include "gtest/gtest.h"
 #include <QTest>
 
-namespace dman {
-
 class ut_search_button_test : public::testing::Test
 {
 public:
     ut_search_button_test();
 };
 
-}
+
 #endif // UT_SEARCH_BUTTON_TEST_H
