@@ -23,18 +23,15 @@
 #include <QTest>
 #include <QObject>
 
-namespace dman {
 
 class ut_SearchEdit_test: public::testing::Test
 {
 //    Q_OBJECT
 public:
     ut_SearchEdit_test();
-    virtual void SetUp() override;
-    virtual void TearDown() override;
+
 protected:
-    SearchEdit *m_se;
+    SearchEdit *m_se = nullptr;
 };
 
-}
 #endif // UT_SEARCHEDIT_TEST_H
